#include "customsAgency.h"
#include <iostream>
#include <stdio.h>

CustomsAgency::CustomsAgency()
:
	Frame_VehicleInfo("Vehicle Information"),
	Frame_DateTime("Date / Time"),
	Frame_BeerFine("Beer / Fine"),
	VBox_Main(false, 5),
	VBox_Tab1_Main(false, 5),
	VBox_Tab2_Main(false, 5),
	Label_Day("Day: "), Label_Month("Month: "), Label_Year("Year: "),
	Label_Make("Make: "), Label_Model("Model: "),
	Label_BeerCases("Number of Beer Cases: "),
	Label_Fine("Fine: "), Label_FineValue("$0.00"),
	Adjustment_Day(1.0, 1.0, 31.0, 1.0, 5.0, 0.0),
	Adjustment_Month(1.0, 1.0, 12.0, 1.0, 5.0, 0.0),
	Adjustment_Year(1950.0, 0.0, 2008.0, 1.0, 100.0, 0.0),
	Adjustment_BeerCases(0.0, 0.0, 50.0, 1.0, 5.0, 0.0),
	SpinButton_Day(Adjustment_Day),
	SpinButton_Month(Adjustment_Month),
	SpinButton_Year(Adjustment_Year),
	SpinButton_BeerCases(Adjustment_BeerCases),
	Button_Add(Gtk::Stock::ADD)
{
	set_title("US Customs Agency - CIS525 Final (GUI)");

	add(VBox_Main);

	//Create actions for menus and toolbars:
	refActionGroup = Gtk::ActionGroup::create();

	//File menu:
	refActionGroup->add( Gtk::Action::create("FileMenu", "_File", "_File") );

	refActionGroup->add( Gtk::Action::create("FileQuit", Gtk::Stock::QUIT),
		sigc::mem_fun(*this, &CustomsAgency::menu_file_quit) );

	//Help menu:
	refActionGroup->add( Gtk::Action::create("HelpMenu", "_Help", "_Help") );

	refActionGroup->add( Gtk::Action::create("HelpAbout", Gtk::Stock::ABOUT),
		sigc::mem_fun(*this, &CustomsAgency::menu_help_about) );

	refUIManager = Gtk::UIManager::create();
	refUIManager->insert_action_group(refActionGroup);
 
	add_accel_group(refUIManager->get_accel_group());

	//Layout the actions in a menubar and toolbar:
	Glib::ustring ui_info = 
				"<ui>"
				"	<menubar name='MenuBar'>"
				"		<menu action='FileMenu'>"
				"			<menuitem action='FileQuit'/>"
				"		</menu>"
				"		<menu action='HelpMenu'>"
				"			<menuitem action='HelpAbout'/>"
				"		</menu>"
				"	</menubar>"
				"</ui>";

	#ifdef GLIBMM_EXCEPTIONS_ENABLED
	try
	{			
		refUIManager->add_ui_from_string(ui_info);
	}
	catch(const Glib::Error& ex)
	{
		std::cerr << "building menus failed: " <<	ex.what();
	}
	#else
	std::auto_ptr<Glib::Error> ex;
	refUIManager->add_ui_from_string(ui_info, ex);
	if(ex.get())
	{ 
		std::cerr << "building menus failed: " <<	ex->what();
	}
	#endif //GLIBMM_EXCEPTIONS_ENABLED
 
	//Get the menubar and toolbar widgets; add them to the main container
	Gtk::Widget* pMenubar = refUIManager->get_widget("/MenuBar");
	if(pMenubar)
		VBox_Main.pack_start(*pMenubar, Gtk::PACK_SHRINK);

	VBox_Main.pack_start(Notebook);

	//Add the tabs:
	Notebook.append_page(VBox_Tab1_Main, "Declaration");
	Notebook.append_page(VBox_Tab2_Main, "Search");

	// START - Vehicle Info frame
	VBox_Tab1_Main.pack_start(Frame_VehicleInfo);

	VBox_VehicleInfo.set_border_width(5);
	Frame_VehicleInfo.add(VBox_VehicleInfo);

	VBox_VehicleInfo.pack_start(HBox_MakeModel, Gtk::PACK_EXPAND_WIDGET, 5);

	HBox_MakeModel.pack_start(VBox_Make, Gtk::PACK_EXPAND_WIDGET, 5);

	Label_Make.set_alignment(Gtk::ALIGN_LEFT);
	VBox_Make.pack_start(Label_Make);

	Entry_Make.set_max_length(15);
	VBox_Make.pack_start(Entry_Make);

	HBox_MakeModel.pack_start(VBox_Model, Gtk::PACK_EXPAND_WIDGET, 5);

	Label_Model.set_alignment(Gtk::ALIGN_LEFT);
	VBox_Model.pack_start(Label_Model);

	Entry_Model.set_max_length(15);
	VBox_Model.pack_start(Entry_Model);
	// END - Vehicle Info frame


	// START - Date/Time Frame
	VBox_Tab1_Main.pack_start(Frame_DateTime);
	VBox_DateTime.set_border_width(5);
	Frame_DateTime.add(VBox_DateTime);

	// Start - Day, month, year
	VBox_DateTime.pack_start(HBox_Date, Gtk::PACK_EXPAND_WIDGET, 5);

	// Day
	Label_Day.set_alignment(Gtk::ALIGN_LEFT);
	VBox_Day.pack_start(Label_Day);
	SpinButton_Day.set_value(1);
	SpinButton_Day.set_wrap();
	VBox_Day.pack_start(SpinButton_Day);
	HBox_Date.pack_start(VBox_Day, Gtk::PACK_EXPAND_WIDGET, 5);

	// Month
	Label_Month.set_alignment(Gtk::ALIGN_LEFT);
	VBox_Month.pack_start(Label_Month);
	SpinButton_Month.set_value(1);
	SpinButton_Month.set_wrap();
	VBox_Month.pack_start(SpinButton_Month);
	HBox_Date.pack_start(VBox_Month, Gtk::PACK_EXPAND_WIDGET, 5);

	// Year
	Label_Year.set_alignment(Gtk::ALIGN_LEFT);
	VBox_Year.pack_start(Label_Year);
	SpinButton_Year.set_value(2007);
	SpinButton_Year.set_wrap();
	//SpinButton_Year.set_size_request(55, -1);
	VBox_Year.pack_start(SpinButton_Year);
	HBox_Date.pack_start(VBox_Year, Gtk::PACK_EXPAND_WIDGET, 5);
	// End - Day, month, year


	// Start - AM/PM radio buttons:
/*
	VBox_DateTime.pack_start(HBox_Time, Gtk::PACK_EXPAND_WIDGET, 5);

	Gtk::RadioButton::Group AMPM_Group = Radio_AM.get_group();
	Radio_PM.set_group(AMPM_Group);
	Radio_AM.set_active();

	HBox_Date.pack_start(Radio_AM, Gtk::PACK_EXPAND_WIDGET, 5);
	HBox_Date.pack_start(Radio_PM, Gtk::PACK_EXPAND_WIDGET, 5);

	// End - AM/PM radio buttons:
*/
	// END - Date/Time Frame

	
	// START - Beer / Fine Frame
	VBox_Tab1_Main.pack_start(Frame_BeerFine);
	HBox_BeerFine.set_border_width(5);
	Frame_BeerFine.add(HBox_BeerFine);

	// Beer Cases
	Label_BeerCases.set_alignment(Gtk::ALIGN_LEFT);
	VBox_BeerCases.pack_start(Label_BeerCases);
	SpinButton_BeerCases.set_wrap(false);
	VBox_BeerCases.pack_start(SpinButton_BeerCases);
	HBox_BeerFine.pack_start(VBox_BeerCases, Gtk::PACK_EXPAND_WIDGET, 5);

	// Fine
	Label_Fine.set_alignment(Gtk::ALIGN_LEFT);
	VBox_Fine.pack_start(Label_Fine);
	VBox_Fine.pack_start(Label_FineValue);
	HBox_BeerFine.pack_start(VBox_Fine, Gtk::PACK_EXPAND_WIDGET, 5);
	// END - Beer / Fine Frame


	//Add button:
	Button_Add.signal_clicked().connect( sigc::mem_fun(*this, &CustomsAgency::on_button_add) );
	VBox_Tab1_Main.pack_start(Button_Add, Gtk::PACK_SHRINK);

	show_all_children();
}

CustomsAgency::~CustomsAgency()
{
}


void CustomsAgency::on_button_add()
{
 	 std::cout << "Day: " << SpinButton_Day.get_value() << std::endl;
 	 std::cout << "Month: " << SpinButton_Month.get_value() << std::endl;
 	 std::cout << "Year: " << SpinButton_Year.get_value() << std::endl;
 	 std::cout << "Year: " << SpinButton_BeerCases.get_value() << std::endl;
}

void CustomsAgency::menu_file_quit()
{
	hide(); //Closes the main window; program ends
}

void CustomsAgency::menu_help_about()
{
	Gtk::MessageDialog dialog(*this, "US Customs Agency - Ver. 1.0");
	dialog.set_secondary_text("This is some explanation.\nCoded by Eric P.\n GUI version for CIS525 final.");

	dialog.run();
}
